Crate pnglitcher

Crate pnglitcher 

Modules

chunk
Chunk types and functions
text_metadata

Structs

AnimationControl
Animation control information
Encoder
PNG Encoder.
FrameControl
Frame control information
Info
PNG info struct
ParameterError
PixelDimensions
Pixel dimensions information
ScaledFloat
An unsigned integer scaled version of a floating point value, equivalent to an integer quotient with fixed denominator (100_000)).
SourceChromaticities
Chromaticities of the color space primaries
StreamWriter
Streaming PNG writer
Transformations
Output transformations
Writer
PNG writer

Enums

AdaptiveFilterType
The filtering method for preprocessing scanline data before compression.
BitDepth
Bit depth of the PNG file. Specifies the number of bits per sample.
BlendOp
How pixels are written into the buffer.
ColorType
Describes how a pixel is encoded.
Compression
The type and strength of applied compression.
DisposeOp
How to reset buffer of an animated png (APNG) at the end of a frame.
EncodingError
FilterType
The byte level filter applied to scanlines to prepare them for compression.
SrgbRenderingIntent
The rendering intent for an sRGB image.
Unit
Physical unit of the pixel dimensions

Functions

duplicate
duplicate_sample
replace
replace_sample
variable_filter
wrong_filter
wrong_filter_sample