Modules
- chunk
- Chunk types and functions
- text_
metadata
Structs
- Animation
Control - Animation control information
- Encoder
- PNG Encoder.
- Frame
Control - Frame control information
- Info
- PNG info struct
- Parameter
Error - Pixel
Dimensions - Pixel dimensions information
- Scaled
Float - An unsigned integer scaled version of a floating point value, equivalent to an integer quotient with fixed denominator (100_000)).
- Source
Chromaticities - Chromaticities of the color space primaries
- Stream
Writer - Streaming PNG writer
- Transformations
- Output transformations
- Writer
- PNG writer
Enums
- Adaptive
Filter Type - The filtering method for preprocessing scanline data before compression.
- BitDepth
- Bit depth of the PNG file. Specifies the number of bits per sample.
- BlendOp
- How pixels are written into the buffer.
- Color
Type - Describes how a pixel is encoded.
- Compression
- The type and strength of applied compression.
- Dispose
Op - How to reset buffer of an animated png (APNG) at the end of a frame.
- Encoding
Error - Filter
Type - The byte level filter applied to scanlines to prepare them for compression.
- Srgb
Rendering Intent - The rendering intent for an sRGB image.
- Unit
- Physical unit of the pixel dimensions